==> worker_2.17.8.orig.tar.bz2: worker-2.17.8/src/functionproto.h <==
/* functionproto.h
 * This file belongs to Worker, a file manager for UN*X/X11.
 * Copyright (C) 2001-2008 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef FUNCTIONPROTO_H
#define FUNCTIONPROTO_H

#include "wdefines.h"
#include <aguix/refcount.hh>

class Datei;
class Worker;
class AGUIX;
class Lister;
class WPUContext;
class List;

class ActionDescr
{
 public:
    ActionDescr() {}
    virtual ~ActionDescr() {}

    virtual List *get_action_list( class WCFiletype *ft ) const = 0;
};

class ActionMessage
{
public:
  ActionMessage( Worker *);
  ~ActionMessage();
  ActionMessage( const ActionMessage &other );
  ActionMessage &operator=( const ActionMessage &other );

  typedef enum {AM_MODE_NORMAL,
                AM_MODE_ONLYACTIVE,
                AM_MODE_DNDACTION,
                AM_MODE_SPECIAL} am_mode_t;
  am_mode_t mode;
  Lister *startLister;
  const class DNDMsg *dndmsg;
  class WCFiletype *filetype;
  RefCount<ActionDescr> m_action_descr;
  
  Worker *getWorker() const;
  const class FileEntry *getFE() const;
  void setFE( const class FileEntry *tfe );
  void setKeyAction( bool nv );
  bool getKeyAction() const;
protected:
  Worker *worker;
  class FileEntry *fe;
  bool m_key_action;
};

class FunctionProto
{
public:
  FunctionProto();
  virtual ~FunctionProto();
  FunctionProto( const FunctionProto &other );
  FunctionProto &operator=( const FunctionProto &other );

  virtual int configure();
  virtual FunctionProto *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();
  virtual bool save(Datei *);
  virtual int run( WPUContext *, ActionMessage * );
  virtual const char *getDescription();
  
  static int presave(Datei*,FunctionProto*);
  int configureWhenAvail();
protected:
  static const char *name;
  bool hasConfigure;
};

void freecoms(List*);

#endif

==> worker-2.18.1.tar.bz2: worker-2.18.1/src/functionproto.h <==
/* functionproto.h
 * This file belongs to Worker, a file manager for UN*X/X11.
 * Copyright (C) 2001-2008,2011 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef FUNCTIONPROTO_H
#define FUNCTIONPROTO_H

#include "wdefines.h"
#include <aguix/refcount.hh>
#include <string>

class Datei;
class Worker;
class AGUIX;
class Lister;
class WPUContext;
class List;

class ActionDescr
{
 public:
    ActionDescr() {}
    virtual ~ActionDescr() {}

    virtual List *get_action_list( class WCFiletype *ft ) const = 0;
};

class ActionMessage
{
public:
  ActionMessage( Worker *);
  ~ActionMessage();
  ActionMessage( const ActionMessage &other );
  ActionMessage &operator=( const ActionMessage &other );

  typedef enum {AM_MODE_NORMAL,
                AM_MODE_ONLYACTIVE,
                AM_MODE_DNDACTION,
                AM_MODE_SPECIAL} am_mode_t;
  am_mode_t mode;
  Lister *startLister;
  const class DNDMsg *dndmsg;
  class WCFiletype *filetype;
  RefCount<ActionDescr> m_action_descr;
  
  Worker *getWorker() const;
  const class FileEntry *getFE() const;
  void setFE( const class FileEntry *tfe );
  void setKeyAction( bool nv );
  bool getKeyAction() const;
protected:
  Worker *worker;
  class FileEntry *fe;
  bool m_key_action;
};

class FunctionProto
{
public:
  FunctionProto();
  virtual ~FunctionProto();
  FunctionProto( const FunctionProto &other );
  FunctionProto &operator=( const FunctionProto &other );

  virtual int configure();
  virtual FunctionProto *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();
  virtual bool save(Datei *);
  virtual int run( WPUContext *, ActionMessage * );
  virtual const char *getDescription();
  
  static int presave(Datei*,FunctionProto*);
  int configureWhenAvail();

  typedef enum {
      CAT_FILETYPE,
      CAT_CURSOR,
      CAT_FILELIST,
      CAT_FILEOPS,
      CAT_SELECTIONS,
      CAT_SETTINGS,
      CAT_SCRIPTING,
      CAT_OTHER
  } command_categories_t;

  static std::string getCategoryName( command_categories_t category );

  virtual command_categories_t getCategory() const;
protected:
  static const char *name;
  bool hasConfigure;
  command_categories_t m_category;
};

void freecoms(List*);

#endif

/* Local Variables: */
/* mode:c++ */
/* End: */
